@@ -1202,7 +1202,7 @@ PHP_FUNCTION(smbclient_read)
 		return;
 	}
 	if (count < 0) {
-		php_error(E_WARNING, "Negative byte count: %ld", count);
+		php_error(E_WARNING, "Negative byte count: " ZEND_LONG_FMT, count);
 		RETURN_FALSE;
 	}
 	STATE_FROM_ZSTATE;
@@ -1253,7 +1253,7 @@ PHP_FUNCTION(smbclient_write)
 		return;
 	}
 	if (count < 0) {
-		php_error(E_WARNING, "Negative byte count: %ld", count);
+		php_error(E_WARNING, "Negative byte count: " ZEND_LONG_FMT, count);
 		RETURN_FALSE;
 	}
 	if (count == 0 || count > str_len) {
@@ -1537,6 +1537,7 @@ PHP_FUNCTION(smbclient_getxattr)
 		/* since version 4.16.9 and 4.17.5 this means success :(
 		 * so there is no way to compute the buffer size
 		 * see https://bugzilla.samba.org/show_bug.cgi?id=14808
+		 * This regression is fixed in 4.18.7 and 4.19.0
 		 */
 		xattr_size = DEFAULT_BUFFER_SIZE;
 		do {
